# -*- coding: utf-8 -*-

# Copyright(C) 2011      Gabriel Kerneis
# Copyright(C) 2010-2011 Jocelyn Jaubert
#
# This file is part of weboob.
#
# weboob is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# weboob is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with weboob. If not, see <http://www.gnu.org/licenses/>.


from .account_history import AccountHistory
from .card_history import CardHistory
from .accounts_list import AccountsList
from .login import LoginPage, ProfilIncomplete, UpdateInfoPage, NewWebsitePage
from .two_authentication import AuthenticationPage
from .investment import AccountMarket, AccountLifeInsurance, InvestmentDetail
from .lifeinsurance_history import LifeInsuranceHistory


class AccountPrelevement(AccountsList):
    pass

__all__ = ['LoginPage',
           'ProfilIncomplete',
           'AccountsList',
           'AccountHistory',
           'CardHistory',
           'UpdateInfoPage',
           'AuthenticationPage',
           'AccountMarket',
           'AccountLifeInsurance',
           'InvestmentDetail',
           'LifeInsuranceHistory',
           'NewWebsitePage',
          ]
